==> reactidsk-0.0.33.tgz: package/lib/components/SuggestionInput/SuggestionInput.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useState } from 'react';
import ListItem from '../ListItem';
import InputField from '../InputField';
import { StyledSuggestionInput, StyledUnorderedList } from './style';
const SuggestionInput = (_a) => {
    var { fetcherSuggestion, children, label, className, loadingText, style, meta, loading, input } = _a, props = __rest(_a, ["fetcherSuggestion", "children", "label", "className", "loadingText", "style", "meta", "loading", "input"]);
    const [isFocus, setIsFocus] = useState(false);
    const { onBlur, onChange } = input || {};
    const handleOnBlur = (_e) => {
        if (!isFocus)
            return;
        setTimeout(() => {
            setIsFocus(false);
        }, 150);
    };
    const handleBlur = (e) => __awaiter(void 0, void 0, void 0, function* () {
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(e);
        handleOnBlur(e);
    });
    const handleFocus = (_e) => {
        setIsFocus(true);
    };
    const handleClick = (e) => {
        onChange === null || onChange === void 0 ? void 0 : onChange(e);
        fetcherSuggestion === null || fetcherSuggestion === void 0 ? void 0 : fetcherSuggestion(e);
    };
    return (React.createElement(StyledSuggestionInput, { className: className, style: style, isFocus: isFocus },
        React.createElement(InputField, Object.assign({ children: label, meta: meta, input: Object.assign(Object.assign({}, input), { onChange: handleClick, onBlur: handleBlur, onFocus: handleFocus, autoComplete: 'off' }) }, props)),
        loading && (React.createElement(StyledUnorderedList, { loading: loading },
            React.createElement(ListItem, null,
                React.createElement("span", null, loadingText)))),
        !loading && children && React.createElement(StyledUnorderedList, { listStyleType: 'none' }, children)));
};
SuggestionInput.LI = ListItem;
SuggestionInput.displayName = 'SuggestionInput';
export default SuggestionInput;

==> reactidsk-0.0.42.tgz: package/lib/components/SuggestionInput/SuggestionInput.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useState } from 'react';
import ListItem from '../ListItem';
import InputField from '../InputField';
import { StyledSuggestionInput, StyledUnorderedList } from './style';
const SuggestionInput = (_a) => {
    var { fetcherSuggestion, children, label, className, loadingText, style, meta, loading: isLoading, input } = _a, props = __rest(_a, ["fetcherSuggestion", "children", "label", "className", "loadingText", "style", "meta", "loading", "input"]);
    const [isFocus, setIsFocus] = useState(false);
    const { onBlur, onChange } = input || {};
    const handleOnBlur = (_e) => {
        if (!isFocus)
            return;
        setTimeout(() => {
            setIsFocus(false);
        }, 150);
    };
    const handleBlur = (e) => __awaiter(void 0, void 0, void 0, function* () {
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(e);
        handleOnBlur(e);
    });
    const handleFocus = (_e) => {
        setIsFocus(true);
    };
    const handleClick = (e) => {
        onChange === null || onChange === void 0 ? void 0 : onChange(e);
        fetcherSuggestion === null || fetcherSuggestion === void 0 ? void 0 : fetcherSuggestion(e);
    };
    return (React.createElement(StyledSuggestionInput, { className: className, style: style, isFocus: isFocus },
        React.createElement(InputField, Object.assign({ children: label, meta: meta, input: Object.assign(Object.assign({}, input), { onChange: handleClick, onBlur: handleBlur, onFocus: handleFocus, autoComplete: 'off' }) }, props)),
        isLoading && (React.createElement(StyledUnorderedList, { isLoading: isLoading },
            React.createElement(ListItem, null, loadingText ? loadingText : React.createElement("span", null, "Na\u010D\u00EDtavam...")))),
        !isLoading && children && React.createElement(StyledUnorderedList, { listStyleType: 'none' }, children)));
};
SuggestionInput.LI = ListItem;
SuggestionInput.displayName = 'SuggestionInput';
export default SuggestionInput;
